.. image:: https://travis-ci.org/rasmunk/projects-site.svg?branch=master
    :target: https://travis-ci.org/rasmunk/projects-site

=============
projects-site
=============

Basic template for providing websites that presents projects and their associated metadata.
